@@ -38,7 +38,7 @@ class Operator:
         return ModOperator(self, other)
 
     def __rmul__(self, other):
-        return MultiplicationOperator(self, other)
+        return MultiplicationOperator(other, self)
 
     def __mul__(self, other):
         return MultiplicationOperator(self, other)
@@ -46,15 +46,15 @@ class Operator:
     def __add__(self, other):
         return AdditionOperator(self, other)
 
+    def __radd__(self, other):
+        return AdditionOperator(other, self)
+
     def __sub__(self, other):
         return SubtractionOperator(self, other)
 
     def __rsub__(self, other):
         return SubtractionOperator(other, self)
 
-    def __radd__(self, other):
-        return AdditionOperator(self, other)
-
     def __neg__(self):
         return NumericalMultiplicationOperator(self, (-1.0))
 
@@ -75,7 +75,6 @@ class Operator:
 
     def __ne__(self, other):
         return ComparisonOperator(self, other, "!=")
-    #def __le__(self,other):
 
 
 class Function(Operator):
